@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2010 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2012 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -50,7 +50,7 @@ int btrfs_check_compatibility(u64 compat, u64 incompat, u64 ro_compat)
     return 0;
 }
 
-int btrfs_mkfs(cdico *d, char *partition)
+int btrfs_mkfs(cdico *d, char *partition, char *fsoptions)
 {
     char command[2048];
     char buffer[2048];
@@ -85,6 +85,9 @@ int btrfs_mkfs(cdico *d, char *partition)
     
     // ---- set the advanced filesystem settings from the dico
     memset(options, 0, sizeof(options));
+
+    strlcatf(options, sizeof(options), " %s ", fsoptions);
+
     if (dico_get_string(d, 0, FSYSHEADKEY_FSLABEL, buffer, sizeof(buffer))==0 && strlen(buffer)>0)
         strlcatf(options, sizeof(options), " -L '%s' ", buffer);
     
